
=====
Usage
=====

This section contains information, including examples, about how to use
*django-email-change* in your existing Django projects or applications.


The email change form link
==========================

To display the link to the email change form, you can use the following code::

    <a href="{% url email_change %}">Change email</a>

